.. root-signals documentation master file, created by
   sphinx-quickstart on Mon May 27 13:49:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: root_signals+bounding_box.svg
   :height: 200

.. raw:: html

  <p align="center">
    <i>Robust AI Skill Management</i>
  </p>

  <p align="center">
      <a href="https://github.com/root-signals/root-python-sdk/releases">
          <img alt="GitHub release"   src="https://img.shields.io/github/release/root-signals/root-python-sdk.svg">
      </a>
      <a href="https://www.python.org/">
              <img alt="Build"   src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg?color=purple">
      </a>
      <a   href="https://github.com/root-signals/root-python-sdk/blob/master/LICENSE">
          <img alt="License"   src="https://img.shields.io/github/license/rootsignals/roots.svg?color=green">
      </a>
  </p>

The Root Signals SDK streamlines the evaluation of your LLM pipelines, to yield insights about their effectiveness. While many tools exist for building the pipelines themselves, quantifying their performance can be challenging.

Root Signals addresses this gap with carefully crafted universal evaluators based on cutting edge LLM research, as well as a framework for systematically adding your own.

Easily integrate with your CI/CD process for continuous monitoring to ensure the performance stays within acceptable limits.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   examples
   setup


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
